Citing Skan
===========

If you use Skan in your work, please cite it as

.. bibliography::
    :filter: key % "NunezIglesias2018"

So far, the following publications rely on Skan:

.. bibliography::
    :list: bullet
    :filter: not key % "NunezIglesias2018"

